
/* 
 * This macro was used to generate histograms for test run May 2017.
 */

void CreateHisto(double hours = 24, int binWidth = 100, double ROImin = 5505, double ROImax = 6695)   // 168 hours = 7 days
{
    // set some parameters
    Double_t backgrHours = 189.4;      // runs 192-199
    Double_t seconds     = hours*3600; // beam time
    Double_t rate        = 30e3;       // Hz
    Double_t vetoThres   = 100;        // keV
    Double_t branching   = 1e-6;
    Double_t dtPileup    = 1000;       // ns

    TString simdir  = "../../output/f20scan/b50/";
    TString datadir = "/home/oliskir/Desktop/f20/data/sorted/";
    const double emin = 0;
    const double emax = 1E4;
    const int bins = (emax - emin) / binWidth;

    vector<string> fname = {"backgr", "allowed_cut_res", "forbidden_res", "pileup_res", "summing_res"};
    vector<string> hname = {"backgr", "allowed", "forbidden", "pileup", "summing"};
    vector<double> sf;
    vector<TH1F*> hist, histVeto;

    // canvas
    TCanvas * c1 = new TCanvas("c1");
        
    int i = 0;
    for (auto& fn : fname) {

        // output histogram names
        TString hn = hname[i];
        TString hnV = hn + "Veto";
        
        if (hn == "backgr") {
            // add files
            TChain * chain = new TChain("data");    
            chain->Add(datadir+"*0192*");    
            chain->Add(datadir+"*0193*");    
            chain->Add(datadir+"*0194*");    
            chain->Add(datadir+"*0195*");    
            chain->Add(datadir+"*0196*");    
            chain->Add(datadir+"*0197*");    
            chain->Add(datadir+"*0198*");    
            chain->Add(datadir+"*0199*"); 
            // histograms
            hist.push_back(new TH1F(hn, hn, bins, emin, emax));
            histVeto.push_back(new TH1F(hnV, hnV, bins, emin, emax));
            // veto cut
            TCut veto("M1 <= 1 && E1 < 140 + 0.21*E0");
            // draw
            chain->Draw("E0>>"+hn, "Z0 != 10");
            chain->Draw("E0>>"+hnV, "Z0 != 10" && veto);
            // scaling factor
            sf.push_back(hours/backgrHours);
        }    
        else {
            TFile *f = TFile::Open(simdir+Form("%s.root", fn.c_str()));
            TTree *t = (TTree*)f -> Get("Detector");
            // histograms
            hist.push_back(new TH1F(hn, hn, bins, emin, emax));
            histVeto.push_back(new TH1F(hnV, hnV, bins, emin, emax));
            // veto cut
            TCut veto = Form("EDepVeto < %.1f", vetoThres);
            // draw
            t->Draw("EDepSignal>>"+hn);
            t->Draw("EDepSignal>>"+hnV, veto);
            // scaling factor
            double norm = ((TParameter<double>*)(t->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal();         double x = rate * seconds / norm;
            if (hn == "forbidden") x *= branching;
            else if (hn == "pileup") x *= dtPileup * 1E-9 * rate;
            sf.push_back(x);
        }
        
        // scale
        hist[i]->Scale(sf[i]);        
        histVeto[i]->Scale(sf[i]);        

        i++;
    }
    

    // print info

    cout << endl;
    cout << " Name    Scaling    Counts_ROI" << endl;
    cout << "---------------------------------" << endl;
    for (int i = 0; i < hist.size(); i++) {
        int binx1 = hist[i]->GetXaxis()->FindBin(ROImin);
        int binx2 = hist[i]->GetXaxis()->FindBin(ROImax);
        double y = hist[i]->Integral(binx1, binx2);
        double yV = histVeto[i]->Integral(binx1, binx2);

        cout << " " << fname[i] << "  " << sf[i] << "  " << Form("%.1f / %.1f",y,yV) << endl;
    }
    cout << "--------------------" << endl;
    

    // "detach" the histograms from file
    for (auto& h : hist) h->SetDirectory(0); 
    for (auto& h : histVeto) h->SetDirectory(0); 
    

    // write histograms to new file
    TString no = "his.root";
    TFile *fo = TFile::Open(no, "recreate");
    for (auto& h : hist) h->Write(); 
    for (auto& h : histVeto) h->Write(); 
    fo -> Close();

	cout << " Histograms written to: " << no << endl << endl;
}
