
/*
 * Magnet scan
 */

void MagnetScan_sim(Int_t bins = 100, Double_t emin = 500, Double_t emax = 2500, Bool_t vetoOn = false) {

    TString dir = "../../output/scan/";
    TString ss = "_c";

    vector<TString> file;
    vector<double> current;
    double ymax = 0;

    double calib = 0.264;
    
    file.push_back(dir + "i26" + "_b" + ".root"); current.push_back(26.0);
    file.push_back(dir + "i24" + "_b" + ".root"); current.push_back(24.0);
    file.push_back(dir + "i22" + ss + ".root"); current.push_back(22.0);
    file.push_back(dir + "i20" + ss + ".root"); current.push_back(20.0);
    file.push_back(dir + "i18" + ss + ".root"); current.push_back(18.0);
    file.push_back(dir + "i16" + ss + ".root"); current.push_back(16.0);

    // source activity
    double A0    = 398e3; // Start activity in Bq
    double years = 8.0;   // years since source was made
    double t12   = 31.6;  // half-life
    double A     = A0 * TMath::Exp(- years * TMath::Log(2) / t12);
    cout << "Activity: " << A << " Bq" << endl;
    
    // intensity of 1.6-MeV line
    double intensity = (0.2522 + 0.0403)/1E3;

    // duration of measurement in minutes
    double duration = 1;
        
    // get histograms
    vector<TH1F*> hist;
    Int_t i=0;
    for (auto& fname : file) {
        TFile * f = new TFile(fname, "READ");
        TString hname = Form("I%.0f", current[i]);
        hist.push_back(new TH1F(hname, hname, bins, emin/calib, emax/calib));
        TTree * t = (TTree*)f->Get("Detector");

        // Normalization
        Double_t norm = ((TParameter<double>*)(t->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal();
	    // Calculate scaling factor
	    Double_t sf = intensity * 60 * duration * A / norm;
        if (i==0) cout << "Scaling factor: " << sf << endl;        

        // veto cut
        TCut cut("");
        if (vetoOn) cut = TCut("PhotonsVeto == 0");
        
        // draw
        t->Draw("PhotonsSignal>>"+hname, cut);
        
        // scale
        hist[i]->Scale(sf);

        // find max
        double y = hist[i]->GetMaximum();
        if (y > ymax) ymax = y;
        
        i++;
    }


    // canvas
    TCanvas * c1 = new TCanvas("c1");

	// Legend
	Double_t xl1=.7, yl1=0.6, xl2=xl1+0.15, yl2=yl1+0.25;
    TLegend *leg = new TLegend(xl1, yl1, xl2, yl2);
          
    // draw histograms      
    i=0;
    for (auto& h : hist) {
        cout << Form("I/I_max=%.0f %%", current[i]) 
             << ",  Peak integral=" << h->Integral(h->FindBin(1400/calib), h->FindBin(1900/calib)) << endl;

        h->GetXaxis()->SetLimits(emin, emax);

        h->SetMaximum(1.2*ymax);

        int col = (i < 4)? i+1 : i+2;
        h->SetLineColor(col);

        int sty = i % 2 + 1;
        h->SetLineStyle(sty);
        
        int wid = i % 2 + 1;
        h->SetLineWidth(wid);

        if (i == 0) h->Draw();
        else h->Draw("same");

        leg -> AddEntry(h, Form("I/I_{max}=%.0f %%", current[i]), "l");  
    
        i++;
    }

    // make pretty    
    gPad->SetLogy(0);
    gPad->SetGrid(0,1);
    gPad->SetTicks();
    
    gStyle->SetOptStat("");
    
    hist[0]->GetXaxis()->SetTitle("Energy (keV)");
    hist[0]->GetYaxis()->SetTitle(Form("Counts / %.0f keV / minute", (emax-emin)/bins));
    
    TString title = "^{207}Bi magnet scan (Simulation)";
    hist[0]->SetTitle(title);

    // legend
    leg -> SetTextSize(15);
    leg -> SetTextFont(133);
    leg -> SetFillColor(0);
    leg -> Draw("same");  
    
    TString fname = "/home/oliskir/Dropbox/Work_ln-s/F20-IGISOL/analysis/figures/";
    fname += "magnet_scan_sim" + ss + ".png";
    c1->Print(fname);                  
}
