
/* 
 * Experiment beta spectrum for various B-field settings 
 * with simulated beta spectrum + measured background superimposed.
 * 1.6-MeV gamma-ray line is used for normalisation.
 */

void ExpScanF20(int binWidth = 50, double ROImin = 1500, double ROImax = 7000, double gEff = 0.00296E-2)
{
    const double emin = 0;
    const double emax = 8E3;
    const int bins = (emax - emin) / binWidth;

    vector<int> bmax = {15, 20, 25, 30, 35, 40, 44, 46, 48, 50};
    vector<int> runs = {366, 332, 367, 333, 368, 334, 369, 360, 361, 358};
    vector<double> minutes = {15, 30, 15, 30, 15, 30, 30, 60, 60, 60};
    vector<double> gCutLow = {1480, 1436, 1480, 1436, 1480, 1436, 1480, 1500, 1500, 1500};
    vector<double> gCutHigh = {1580, 1534, 1580, 1534, 1580, 1534, 1580, 1600, 1600, 1600};
/*
    vector<int> bmax = {20, 30, 40, 46, 48, 50};
    vector<int> runs = {332, 333, 334, 360, 361, 358};
    vector<double> minutes = {30, 30, 30, 60, 60, 60};
    vector<double> gCutLow = {1436, 1436, 1436, 1500, 1500, 1500};
    vector<double> gCutHigh = {1534, 1534, 1534, 1600, 1600, 1600};
*/    
    TString datadir = "/home/oliskir/Desktop/f20/data/sorted/new/";

    // canvas
    TCanvas * c1 = new TCanvas("c1");


    int i = 0;
    for (auto& b : bmax) {

        Double_t hours   = minutes[i]/60;
        Double_t seconds = minutes[i]*60;

        // ----------- background measurement --------------- //
        double backgrHours = 11.5;
        // add files
        TChain * chain = new TChain("data");    
        chain->Add(datadir+"*0311*");    
        // histogram
        TH1F * hbackgr = new TH1F("backgr", "backgr", bins, emin, emax);
        // draw
        chain->Draw("E0>>backgr", "Z0 != 10");
        // scaling factor
        hbackgr->Scale(hours/backgrHours);
        // -------------------------------------------------- //

        // --------- beta-spectrum measurement ------- //
        TChain * cexp = new TChain("data");    
        cexp->Add(datadir+Form("*0%i*", runs[i]));    
        // histogram
        TH1F * hbeta  = new TH1F("beta", "beta", bins, emin, emax);
        TH1F * hgamma = new TH1F("gamma", "gamma", 1000, 0, 3000);
        // draw
        cexp->Draw("E0>>beta", "Z0 != 10");
        cexp->Draw("E2>>gamma", "Z2 != 10");
        // integrate 1.6-MeV peak
        int binx1 = hgamma->GetXaxis()->FindBin(gCutLow[i]);
        int binx2 = hgamma->GetXaxis()->FindBin(gCutHigh[i]);
        double gN = hgamma->Integral(binx1, binx2);
        // -------------------------------------------------- //

        // -------------- beta-spectrum simulation -------------- //
        // histogram
        TH1F * h = new TH1F("dummy", "dummy", bins, emin, emax);
        double decays = 1;        
        if (i != 0 && i != 2 && i != 4 && i != 6) { // **** TEMPORARY FIX ****
            TString fname = Form("b%i/allowed_bmax%i_res.root", b, 100*b);
            TString hname = Form("h%i", b);
            TFile * f = new TFile(fname, "READ");
            TTree * t = (TTree*)f->Get("Detector");
            // histogram
            h = new TH1F(hname, hname, bins, emin, emax);
            // draw
            t->Draw("EDepSignal>>"+hname, "EDepSignal > 100");
            // scaling factor
            double norm = ((TParameter<double>*)(t->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal(); 
            decays = gN / gEff;        
            double x = decays / norm;
            // scale
            h->Scale(x);        
            // add background
            h->Add(hbackgr);
        }
        // ---------------------------------------------------- //
        
        // draw
        hbeta->SetMaximum(5*hbeta->GetMaximum());
        hbeta->SetLineColor(1);
        hbeta->SetLineWidth(1);
        hbeta->SetLineStyle(1);
        hbeta->Draw("hist");

        h->SetLineColor(2);
        h->Draw("histsame");

        hbackgr->SetLineColor(4);
        hbackgr->SetLineStyle(2);
        hbackgr->Draw("histsame");        


        // integrate
        binx1 = h->GetXaxis()->FindBin(ROImin);
        binx2 = h->GetXaxis()->FindBin(ROImax);
        double simCounts = h->Integral(binx1, binx2);
        double expCounts = hbeta->Integral(binx1, binx2);


        // make pretty
        hbeta->SetTitle(Form("%.0f min at B_{max} = %.2f T", minutes[i], 0.01*(double)b));
        hbeta->SetMinimum(0.5);
        hbeta->GetXaxis()->SetTitle("Energy (keV)");        
        hbeta->GetYaxis()->SetTitle(Form("Counts / %i keV", binWidth)); 

        double yt = 0.7*h->GetMaximum(); 
        TLatex *tx = new TLatex(5500, yt, Form("#splitline{Counts %.1f-%.1f MeV:}{#splitline{SIM: %.1E counts*}{EXP: %.1E counts}}", ROImin/1000, ROImax/1000, simCounts, expCounts));
        tx->SetTextAlign(11);
        tx->SetTextColor(1);
        tx->SetTextFont(43);
        tx->SetTextSize(16);
        tx->Draw("same");

        tx = new TLatex(5500, 0.1*yt, "* Normalized to 1.6-MeV #gamma-ray");
        tx->SetTextAlign(11);
        tx->SetTextColor(1);
        tx->SetTextFont(43);
        tx->SetTextSize(12);
        tx->Draw("same");
        
        gPad->SetLogy();
        gPad->SetGrid();
        gPad->Update();
        gStyle->SetOptStat("");
        
	    Double_t xl1=.67, yl1=0.5, xl2=xl1+0.22, yl2=yl1+0.11;
        TLegend * leg = new TLegend(xl1, yl1, xl2, yl2);
        leg -> AddEntry(h, "Sim #beta + Backgr", "l");  
        leg -> AddEntry(hbackgr, "Backgr", "l");  
        leg -> AddEntry(hbeta, "Exp #beta", "l");  
        leg -> SetTextSize(15);
        leg -> SetTextFont(133);
        leg -> Draw("same");            

        cout << " B_max:  " << 0.01*b << " T" << endl;
        cout << "Rate (based on gammas): " << Form("%.1f", decays / seconds / 1E3) << " kHz" << endl;
        cout << "Rate (based on betas): " << Form("%.1f", expCounts / simCounts * decays / seconds / 1E3) << " kHz" << endl;

        c1->Print(Form("/home/oliskir/Desktop/specs/expf20spec_bmax%i.png", 100*b));

        cin.get();
        i++;
    }
}
